==> nile_api-0.2.6.tar.gz: nile_api-0.2.6/nile_api/api/organizations/remove_user_from_org.py <==
from typing import Any, Dict

import httpx

from ...client import Client
from ...types import Response


def _get_kwargs(
    workspace: str,
    org: str,
    user: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/workspaces/{workspace}/orgs/{org}/users/{user}".format(
        client.base_url, workspace=workspace, org=org, user=user
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "delete",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    workspace: str,
    org: str,
    user: str,
    *,
    client: Client,
) -> Response[Any]:
    """Remove a user from an organization by user id

    Args:
        workspace (str):
        org (str):
        user (str):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        org=org,
        user=user,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    workspace: str,
    org: str,
    user: str,
    *,
    client: Client,
) -> Response[Any]:
    """Remove a user from an organization by user id

    Args:
        workspace (str):
        org (str):
        user (str):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        org=org,
        user=user,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)

==> nile_api-0.2.8.tar.gz: nile_api-0.2.8/nile_api/api/organizations/remove_user_from_org.py <==
from http import HTTPStatus
from typing import Any, Dict

import httpx

from ...client import Client
from ...types import Response


def _get_kwargs(
    workspace: str,
    org: str,
    user: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/workspaces/{workspace}/orgs/{org}/users/{user}".format(
        client.base_url, workspace=workspace, org=org, user=user
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "delete",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    workspace: str,
    org: str,
    user: str,
    *,
    client: Client,
) -> Response[Any]:
    """Remove a user from an organization by user id

    Args:
        workspace (str):
        org (str):
        user (str):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        org=org,
        user=user,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    workspace: str,
    org: str,
    user: str,
    *,
    client: Client,
) -> Response[Any]:
    """Remove a user from an organization by user id

    Args:
        workspace (str):
        org (str):
        user (str):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        org=org,
        user=user,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)
